// This  skeleton file was automatically created by 
//            pkgmaker 0.1
//            Thursday, December 11 1997
// 
// Module: CalResponse
// Author: Hassan Siddiqui
//
// Description: 
// Provides a clean interface to CAL response data.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: CalResponse.h,v 1.1 2000/09/21 15:34:35 hsiddiqu Exp $

#ifndef CalResponse_H
#define CalResponse_H

// General classes

#include <string>
#include <iostream>
#include <vector>

// SAS-specific classes
#include "CalServer.h"
#include "Redistribution.h"

// Utility functions
#include "Tracer.h"

// Local classes
#include "GenericResponse.h"

/********************************
 *
 * class CalResponse
 *
 * Interface to Cal response data.
 *
 *********************************/

class CalResponse : public GenericResponse
{

public:

  void check();

  /** Constructors */
  CalResponse();

  /** Initialisation routines - called from derived classes. */

  /* Provides the entire range of redistribution available from the CAL */

  /* Initialise using CAL ebins */
   void createWithCalEbins (
		unsigned minOutputChannel,
		unsigned nOutputChannels,
		unsigned outputChannelWidth);

/* Initialise using user-defined ebins */
  void createWithUserEbins (
			    unsigned minOutputChannel,
			    unsigned nOutputChannels,
			    unsigned outputChannelWidth,
			    const BinnedAxis * ebins
			    );

  /* Destructors */
  ~CalResponse();


  /** Channel range accessors */
  const unsigned   firstChannel() const;
  const unsigned   lastChannel() const;


  /** Response Accessors */
  unsigned                 ebinFirstIndex() const;
  unsigned                 numberOfEbins() const;
  const Bin ebins(unsigned row) const;
  const vector<double>         responseVector ( unsigned row ) const;
  const vector<double>         responseVector ( double energy ) const;

  /* Ebounds Accessor 
   * Note the size and range corresponds to that specified for the channel,
   * so no accessors are needed to cover this. */

  const BinnedAxis * ebounds() const;

private:

  /* Core initialisation */
   void create (
		unsigned minOutputChannel,
		unsigned nOutputChannels,
		unsigned outputChannelWidth);


  /* Pad vector with zeros, or truncate vector, to a given size. */
  const vector<double> resizeVector( const vector<double> & in, 
				     unsigned nelements) const;


  unsigned _lastChannel;
  
  double _energyLow;
  double _energyHigh;

  unsigned _rowLow;
  unsigned _rowHigh;
  unsigned _nrows;

protected:

  CanonicalRedist *  _rmf; 
  const BinnedAxis * _ebins;
  const BinnedAxis * _eboundsAxis;
  EventGrades _eventGrade;
};

#endif




