// 
// Module: CorePosData
// Author: Richard Saxton
//
// Description: Methods for accessing the DSS and position information
//               from the spectrum
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: CorePosData.h,v 1.3 2000/10/20 17:40:23 hsiddiqu Exp $

#ifndef CorePosData_H
#define CorePosData_H

/* General */

/* SAS-specific classes */
#include "Xmm.h"
#include "CalCommon.h"
#include "CalServer.h"
#include "CcdQuantumDataServer.h"
#include "Tracer.h"
#include "dss.h"

/* Local classes */
#include "PixCoords.h"
#include "PositionUtils.h"

class CorePosData 
{
public:

  /** Constructors  */
  CorePosData( DataSet * spectrumset , Table * spectrumtable );

  /**  Destructors  */
  ~CorePosData();

  /* Get the centre of the source box in Raw pixels */
  PixCoords centre_raw()  const;

  /* Get the pattern code */
  EventGrades patternCode()  const;

  /* Dummy a spatial region if timing or burst mode */
  void addDetRegion( PositionUtils * putils );

private:

  /** Members */

  DataSubspace  * _dss;

  Xmm::Instrument       _instrumentID;

  const PosWCS *      _poswcs;

  PositionUtils * _positionUtils;

  /* Source position in detector coordinates */
  double _sourcedetx;
  double _sourcedety;

};
#endif
