// Module: ResponseRow.h
// Author: Hassan Siddiqui
//
// Description: Classes which allow the response matrix to be groups.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: ResponseRow.h,v 1.2 2000/03/07 13:49:44 hsiddiqu Exp $

#ifndef ResponseRow_H
#define ResponseRow_H


/* General classes */
#include "list.h"

/* SAS-specific classes */
#include "Dal.h"
#include "Tracer.h"

/* Local classes */
#include "ResponseGrouping.h"
#include "MatrixColumn.h"

/***********************************************************
 *
 * class ResponseRow
 *
 * Contains statistics (# groups, # elements > threshold ) 
 * and grouped data for a row within the response matrix 
 * Later, this might be split into two classes: none which generates the statistics
 * and the other which generates statistics as well as the grouped data structure.
 *
 ***********************************************************/

class ResponseRow : public list<ResponseGroup>
{

 public:

  /* Use constructor using as input the row of interest 
   * of the raw rmf as input to generate a grouped response.
   */

  ResponseRow( const vector<double>& response, double threshold); 

  const vector<double> expanded() const;

  void writeTo(unsigned long row,
	       MatrixColumn * matrixColData, 
	       ColumnData * n_grpColData,
	       ColumnData * f_chanColData,
	       ColumnData * n_chanColData,
               unsigned     tlmin ) const;

  /* Accessors */

  int ngroups() const;

  int nresponse_elements() const;

  double threshold() const;

  /* Suppress default constructor */
  ResponseRow();

private:

  double _threshold;
  int _ngroups;
  int _nresponse_elements;

};

#endif




